@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/lib/config_default.php,v 1.27.2.3 2007/12/26 01:47:20 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/lib/config_default.php,v 1.27.2.9 2008/12/12 12:20:22 wurley Exp $
 
 /**
  * Configuration processing and defaults.
@@ -84,10 +84,18 @@ class Config {
 			'desc'=>'Array of attributes that should show a the time when showing the jscalendar',
 			'default'=>array(''));
 
+		$this->default->appearance['disable_default_template'] = array(
+			'desc'=>'Disabled the Default Template',
+			'default'=>false);
+
 		$this->default->appearance['hide_debug_info'] = array(
 			'desc'=>'Hide the features that may provide sensitive debugging information to the browser',
 			'default'=>true);
 
+		$this->default->appearance['timezone'] = array(
+			'desc'=>'Define our timezone, if not defined in php.ini',
+			'default'=>null);
+
 		/** Language
 		 * The language setting. If you set this to 'auto', phpLDAPadmin will
 		 * attempt to determine your language automatically. Otherwise, available
@@ -189,9 +197,13 @@ class Config {
 			'desc'=>'LDAP attribute to show in the tree',
 			'default'=>'%rdn');
 
+		$this->default->appearance['tree_height'] = array(
+			'desc'=>'Pixel height of the tree browser',
+			'default'=>null);
+
 		$this->default->appearance['tree_width'] = array(
-			'desc'=>'Pixel width of the left frame view (tree browser)',
-			'default'=>320);
+			'desc'=>'Pixel width of the tree browser',
+			'default'=>null);
 
 		/**
 		 * Tree display filter
@@ -316,7 +328,7 @@ class Config {
 			'default'=>null);
 
 		$this->default->debug['addr'] = array(
-			'desc'=>'IP address of PLA client to provide debugging info.',
+			'desc'=>'IP address of client to provide debugging info.',
 			'default'=>null);
 
 		$this->default->debug['append'] = array(
@@ -476,33 +488,36 @@ class Config {
 			'default'=>array('cn','sn','uid','postalAddress','telephoneNumber'));
 	}
 
+	private function getConfigArray($usecache=true) {
+		global $CACHE;
+
+		if ($usecache && isset($CACHE[__METHOD__]))
+			return $CACHE[__METHOD__];
+
+		foreach ($this->default as $key => $vals)
+			$CACHE[__METHOD__][$key] = $vals;
+
+		foreach ($this->custom as $key => $vals)
+			foreach ($vals as $index => $val)
+				$CACHE[__METHOD__][$key][$index]['value'] = $val;
+
+		return $CACHE[__METHOD__];
+	}
+
+	/**
+	 * Get a configuration value.
+	 */
 	public function GetValue($key,$index) {
+		$config = $this->getConfigArray();
 
-		$value = null;
+		if (! isset($config[$key]))
+			error(sprintf('A call was made in [%s] to GetValue requesting [%s] that isnt predefined.',
+				basename($_SERVER['PHP_SELF']),$key),'error',null,true);
 
-		if (! isset($this->default->$key))
-			pla_error(sprintf('A call was made in [%s] to GetValue requesting [%s] that isnt predefined.',
-				basename($_SERVER['PHP_SELF']),$key));
-		else
-			$default = $this->default->$key;
+		if (! isset($config[$key][$index]))
+			error(sprintf('Requesting an index [%s] in key [%s] that isnt predefined.',$index,$key),'error',null,true);
 
-		if (! isset($default[$index]))
-			pla_error("Requesting a index [$index] that isnt predefined.");
-		else
-			$default = $default[$index];
-
-		if (isset($default['default']))
-			$value = $default['default'];
-
-		if (isset($this->custom->$key)) {
-			$custom = $this->custom->$key;
-
-			if (isset($custom[$index]))
-				$value = $custom[$index];
-		}
-
-		//print "Returning [$value] for key [$key], index [$index]<BR>";
-		return $value;
+		return isset($config[$key][$index]['value']) ? $config[$key][$index]['value'] : $config[$key][$index]['default'];
 	}
 
 	/**
@@ -515,23 +530,23 @@ class Config {
 				if (isset($this->default->$masterkey)) {
 
 					if (! is_array($masterdetails))
-						pla_error("Error in configuration file, [$masterdetails] should be an ARRAY.");
+						error(sprintf('Error in configuration file, [%s] should be an ARRAY.',$masterdetails),'error',null,true);
 
 					foreach ($masterdetails as $key => $value) {
 						# Test that the key is correct.
 						if (! in_array($key,array_keys($this->default->$masterkey)))
-							pla_error("Error in configuration file, [$key] has not been defined as a PLA configurable variable.");
+							error(sprintf('Error in configuration file, [%s] has not been defined as a configurable variable.',$key),'error',null,true);
 
 						# Test if its should be an array or not.
 						if (is_array($this->default->{$masterkey}[$key]['default']) && ! is_array($value))
-							pla_error("Error in configuration file, {$masterkey}['$key'] SHOULD be an array of values.");
+							error(sprintf('Error in configuration file, %s[\'%s\'] SHOULD be an array of values.',$masterkey,$key),'error',null,true);
 
 						if (! is_array($this->default->{$masterkey}[$key]['default']) && is_array($value))
-							pla_error("Error in configuration file, {$masterkey}['$key'] should NOT be an array of values.");
+							error(sprintf('Error in configuration file, %s[\'%s\'] should NOT be an array of values.',$masterkey,$key),'error',null,true);
 					}
 
 				} else {
-					pla_error("Error in configuration file, [$masterkey] has not been defined as a PLA MASTER configurable variable.");
+					error(sprintf('Error in configuration file, [%s] has not been defined as a MASTER configurable variable.',$masterkey),'error',null,true);
 				}
 			}
 		}
@@ -627,7 +642,8 @@ class Config {
 	 */
 	public function getFriendlyHTML($attr) {
 		if ($this->haveFriendlyName($attr))
-			return sprintf('<acronym title="%s %s">%s</acronym>',_('Alias for'),$attr,htmlspecialchars($this->getFriendlyName($attr)));
+			return sprintf('<acronym title="%s %s">%s</acronym>',
+				_('Alias for'),$attr,htmlspecialchars($this->getFriendlyName($attr)));
 		else
 			return $attr;
 	}
